==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/files/l10n/ms_MY.js <==
OC.L10N.register(
    "files",
    {
    "No file was uploaded. Unknown error" : "Tiada fail dimuatnaik. Ralat tidak diketahui.",
    "There is no error, the file uploaded with success" : "Tiada ralat berlaku, fail berjaya dimuatnaik",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Saiz fail yang dimuatnaik melebihi MAX_FILE_SIZE yang ditetapkan dalam borang HTML",
    "The uploaded file was only partially uploaded" : "Fail yang dimuatnaik tidak lengkap",
    "No file was uploaded" : "Tiada fail dimuatnaik",
    "Missing a temporary folder" : "Direktori sementara hilang",
    "Failed to write to disk" : "Gagal untuk disimpan",
    "Files" : "Fail-fail",
    "Home" : "Rumah",
    "Upload cancelled." : "Muatnaik dibatalkan.",
    "Rename" : "Namakan",
    "Delete" : "Padam",
    "Download" : "Muat turun",
    "Pending" : "Dalam proses",
    "Error" : "Ralat",
    "Name" : "Nama",
    "Size" : "Saiz",
    "Modified" : "Dimodifikasi",
    "_%n folder_::_%n folders_" : [""],
    "_%n file_::_%n files_" : [""],
    "_Uploading %n file_::_Uploading %n files_" : [""],
    "_matches '{filter}'_::_match '{filter}'_" : [""],
    "File handling" : "Pengendalian fail",
    "Maximum upload size" : "Saiz maksimum muat naik",
    "max. possible: " : "maksimum:",
    "Save" : "Simpan",
    "Settings" : "Tetapan",
    "New" : "Baru",
    "Text file" : "Fail teks",
    "Folder" : "Folder",
    "Upload" : "Muat naik",
    "Cancel upload" : "Batal muat naik",
    "Upload too large" : "Muatnaik terlalu besar",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fail yang cuba dimuat naik melebihi saiz maksimum fail upload server",
    "Files are being scanned, please wait." : "Fail sedang diimbas, harap bersabar."
},
"nplurals=1; plural=0;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files/l10n/ms_MY.js <==
OC.L10N.register(
    "files",
    {
    "No file was uploaded. Unknown error" : "Tiada fail dimuatnaik. Ralat tidak diketahui.",
    "There is no error, the file uploaded with success" : "Tiada ralat berlaku, fail berjaya dimuatnaik",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Saiz fail yang dimuatnaik melebihi MAX_FILE_SIZE yang ditetapkan dalam borang HTML",
    "The uploaded file was only partially uploaded" : "Fail yang dimuatnaik tidak lengkap",
    "No file was uploaded" : "Tiada fail dimuatnaik",
    "Missing a temporary folder" : "Direktori sementara hilang",
    "Failed to write to disk" : "Gagal untuk disimpan",
    "Files" : "Fail-fail",
    "Home" : "Rumah",
    "Upload cancelled." : "Muatnaik dibatalkan.",
    "Rename" : "Namakan",
    "Delete" : "Padam",
    "Download" : "Muat turun",
    "Pending" : "Dalam proses",
    "Error" : "Ralat",
    "Name" : "Nama",
    "Size" : "Saiz",
    "Modified" : "Dimodifikasi",
    "You created %1$s" : "Anda telah membina %1$s",
    "%2$s created %1$s" : "%2$s membina %1$s",
    "You changed %1$s" : "Anda menukar %1$s",
    "File handling" : "Pengendalian fail",
    "Maximum upload size" : "Saiz maksimum muat naik",
    "max. possible: " : "maksimum:",
    "Save" : "Simpan",
    "Settings" : "Tetapan",
    "New" : "Baru",
    "Text file" : "Fail teks",
    "Folder" : "Folder",
    "Upload" : "Muat naik",
    "Cancel upload" : "Batal muat naik",
    "Upload too large" : "Muatnaik terlalu besar",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fail yang cuba dimuat naik melebihi saiz maksimum fail upload server",
    "Files are being scanned, please wait." : "Fail sedang diimbas, harap bersabar."
},
"nplurals=1; plural=0;");
